@@ -17,7 +17,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0R (Compaq Armada M700)
  *
-$Id: battstat.h,v 1.21.2.1 2004/05/20 09:55:28 kmaraas Exp $
+$Id: battstat.h,v 1.23 2004/08/03 14:22:29 davyd Exp $
  */
 
 #define DEBUG 0
@@ -150,7 +150,7 @@ void help_cb (BonoboUIComponent *, ProgressData *, const char *);
 void suspend_cb (BonoboUIComponent *, ProgressData *, const char *);
 void destroy_about (GtkWidget *, gpointer);
 void about_cb (BonoboUIComponent *, ProgressData *, const char *);
-void change_size(PanelApplet *, gint, gpointer);
+void size_allocate(PanelApplet *, GtkAllocation *, gpointer);
 void change_background(PanelApplet *a, PanelAppletBackgroundType type, 
 		GdkColor *color, GdkPixmap *pixmap, ProgressData *battstat);	
 gint create_layout(ProgressData *battstat);
