@@ -24,7 +24,6 @@
 #include <libgnome/libgnome.h>
 #include <libgnomeui/libgnomeui.h>
 #include <panel-applet.h>
-#include <egg-screen-exec.h>
 
 #include "drivemount.h"
 #include "properties.h"
@@ -161,7 +160,7 @@ static IconData icon_list[] = {
 	 NULL}
 };
 
-static gint icon_list_count = 7;
+const int icon_list_count = 7;
 
 /* Bonobo Verbs for our popup menu */
 static const BonoboUIVerb applet_menu_verbs [] = {
@@ -281,6 +280,7 @@ create_drive_widget (PanelApplet *applet)
 	dd->applet = GTK_WIDGET (applet);
 
 	dd->about_dialog = NULL;
+	dd->prop_dialog = NULL;
 
 	properties_load (dd);
 
@@ -403,14 +403,17 @@ destroy_drive_widget (GtkWidget *widget, gpointer data)
 {
 	DriveData *dd = data;
 
-	if (dd->error_dialog != NULL) {
+	gtk_timeout_remove (dd->timeout_id);
+
+	if (dd->error_dialog != NULL)
 		gtk_widget_destroy (dd->error_dialog);
-		dd->error_dialog = NULL;
-	}
 
 	if (dd->about_dialog != NULL)
 		gtk_widget_destroy (dd->about_dialog);
 
+	if (dd->prop_dialog != NULL)
+		gtk_widget_destroy (dd->prop_dialog);
+
 	g_free (dd->custom_icon_in);
 	g_free (dd->custom_icon_out);
 
@@ -434,9 +437,12 @@ browse_cb (BonoboUIComponent *uic,
 		return;
 
 	command = g_strdup_printf ("nautilus %s", drivemount->mount_point);
-	egg_screen_execute_command_line_async (
-		gtk_widget_get_screen (drivemount->applet), command, &error);
+
+	gdk_spawn_command_line_on_screen (gtk_widget_get_screen (GTK_WIDGET (drivemount->applet)),
+			command, &error); 
+
 	g_free (command);
+
 	if (error) {
 		GtkWidget *dialog;
 		char *msg;
@@ -491,8 +497,8 @@ help_cb (BonoboUIComponent *uic,
      						      GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
 	}
 
-	egg_help_display_desktop_on_screen (
-			applet_program, "drivemount", "drivemount", "drivemount",
+	gnome_help_display_desktop_on_screen (
+			applet_program, "drivemount", "drivemount", NULL,
 			gtk_widget_get_screen (GTK_WIDGET (drivemount->applet)),
 			&error);
 
@@ -737,10 +743,14 @@ update_pixmap (DriveData *dd, gint t)
 			height = ICON_HEIGHT;
 		}
 
-		if (dd->orient == PANEL_APPLET_ORIENT_LEFT
-		    || dd->orient == PANEL_APPLET_ORIENT_RIGHT || hint <= 36) {
+		if ((dd->orient == PANEL_APPLET_ORIENT_LEFT
+		     || dd->orient == PANEL_APPLET_ORIENT_RIGHT) && hint > 36) {
 			pmap_d_in = icon_list[pixmap].pmap_h_in;
 			pmap_d_out = icon_list[pixmap].pmap_h_out;
+		} else if ((dd->orient == PANEL_APPLET_ORIENT_UP
+		     || dd->orient == PANEL_APPLET_ORIENT_DOWN) && hint <= 36) {
+		        pmap_d_in = icon_list[pixmap].pmap_h_in;
+			pmap_d_out = icon_list[pixmap].pmap_h_out;
 		} else {
 			gint tmp;
 
