@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.87 2004/08/16 08:44:40 davyd Exp $ */
+/* $Id: gweather-applet.c,v 1.87.2.1 2004/10/13 12:06:46 kmaraas Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -283,27 +283,27 @@ applet_destroy (GtkWidget *widget, GWeatherApplet *gw_applet)
 	
     if (gw_applet->gweather_info->metar_handle) {
        gnome_vfs_async_cancel(gw_applet->gweather_info->metar_handle);
-       gw_applet->gweather_info->metar_handle = 0;
+       gw_applet->gweather_info->metar_handle = NULL;
     }
 
     if (gw_applet->gweather_info->iwin_handle) {
        gnome_vfs_async_cancel(gw_applet->gweather_info->iwin_handle);
-       gw_applet->gweather_info->iwin_handle = 0;
+       gw_applet->gweather_info->iwin_handle = NULL;
     }
 
     if (gw_applet->gweather_info->wx_handle) {
        gnome_vfs_async_cancel(gw_applet->gweather_info->wx_handle);
-       gw_applet->gweather_info->wx_handle = 0;
+       gw_applet->gweather_info->wx_handle = NULL;
     }
 
     if (gw_applet->gweather_info->met_handle) {
        gnome_vfs_async_cancel(gw_applet->gweather_info->met_handle);
-       gw_applet->gweather_info->met_handle = 0;
+       gw_applet->gweather_info->met_handle = NULL;
     }
 
     if (gw_applet->gweather_info->bom_handle) {
        gnome_vfs_async_cancel(gw_applet->gweather_info->bom_handle);
-       gw_applet->gweather_info->bom_handle = 0;
+       gw_applet->gweather_info->bom_handle = NULL;
     }
 }
 
