@@ -76,6 +76,9 @@
 #elif defined HAVE_DMEDIA_AUDIO_H
 #define IRIX_API
 #include <dmedia/audio.h>
+#elif defined HAVE_SYS_AUDIO_H
+#include <sys/audio.h>
+#define AIX_API
 #elif defined HAVE_GSTREAMER
 #define GSTREAMER_API
 #include <gst/gst.h>
@@ -95,6 +98,9 @@
 #ifdef IRIX_API
 #define VOLUME_MAX 255
 #endif
+#ifdef AIX_API
+#define VOLUME_MAX 160
+#endif
 #ifdef GSTREAMER_API
 #define VOLUME_MAX 100
 #define ALLOW_PREFERENCES
@@ -193,6 +199,11 @@ static void mixer_ui_component_event (BonoboUIComponent *comp,
 			  MixerData                    *data);
 void add_atk_namedesc (GtkWidget *widget, const gchar *name, const gchar *desc);
 
+#ifdef AIX_API
+static gint mstvolfd = -1; /* Used to change the master volume level */
+#define MAX_MPX_CHAN_LEN 20
+#define DEFAULT_MST_VOLUME 100
+#endif
 static gint mixerfd = -1;
 static gchar *run_mixer_cmd = NULL;
 
@@ -503,6 +514,23 @@ openMixer(const gchar *device_name, MixerData *data)
 	 * access the default output port.
 	 */
 	mixerfd = ALgetparams(AL_DEFAULT_DEVICE, pv_buf, MAX_PV_BUF);
+#endif
+#ifdef AIX_API
+	gchar iomixchannel[MAX_MPX_CHAN_LEN];
+	gchar mstvolchannel[MAX_MPX_CHAN_LEN];
+	
+	/* Construct the string to use the iomix multiplex channel
+         * of the device */
+	sprintf(iomixchannel, "%s%s", device_name, "/iomix");
+	sprintf(mstvolchannel, "%s%s", device_name, "/mstvol");
+
+	mstvolfd = open (mstvolchannel, O_WRONLY);
+	if (mstvolfd < 0) {
+		/* probably should die more gracefully */		
+		return FALSE;
+	}
+
+	mixerfd = open(iomixchannel, O_WRONLY);
 #endif
 	if (mixerfd < 0) {
 		/* probably should die more gracefully */		
@@ -564,6 +592,15 @@ readMixer(MixerData *data)
 	(void) ALgetparams(AL_DEFAULT_DEVICE, pv_buf, MAX_PV_BUF);
 	return (pv_buf[1] + pv_buf[3]) / 2;
 #endif
+#ifdef AIX_API
+	gint rc;
+	audio_channel_status info_channels;
+	
+	info_channels.channel_count = 0;
+	rc = ioctl (mixerfd, AUDIO_CHANNEL_STATUS, &info_channels);
+	if (rc < 0) return DEFAULT_MST_VOLUME;
+	else return info_channels.master_volume;
+#endif /* AIX_API */
 }
 
 static void
@@ -603,6 +640,12 @@ setMixer(gint vol, MixerData *data)
 	pv_buf[1] = pv_buf[3] = tvol;
 	(void) ALsetparams(AL_DEFAULT_DEVICE, pv_buf, MAX_PV_BUF);
 #endif
+#ifdef AIX_API
+	int master_volume;
+
+	master_volume = (int)CLAMP (vol, 0, VOLUME_MAX);
+	ioctl (mstvolfd, AUDIO_MASTER_VOLUME, &master_volume);
+#endif
 }
 
 static void
@@ -1356,7 +1399,7 @@ mixer_about_cb (BonoboUIComponent *uic,
                 return;
         }
         
-        file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "mixer/gnome-mixer-applet.png", TRUE, NULL);
+        file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-mixer-applet.png", TRUE, NULL);
         pixbuf = gdk_pixbuf_new_from_file (file, NULL);
         g_free (file);
 
@@ -1375,7 +1418,7 @@ mixer_about_cb (BonoboUIComponent *uic,
 
 	gtk_window_set_wmclass (GTK_WINDOW(data->about_dialog), "volume control", "Volume Control");
 
-	gnome_window_icon_set_from_file (GTK_WINDOW (data->about_dialog), GNOME_ICONDIR"/mixer/gnome-mixer-applet.png");
+	gnome_window_icon_set_from_file (GTK_WINDOW (data->about_dialog), GNOME_ICONDIR "gnome-mixer-applet.png");
         
 	g_signal_connect (G_OBJECT (data->about_dialog), "destroy",
                           G_CALLBACK (gtk_widget_destroyed),
@@ -1514,7 +1557,7 @@ mixer_pref_cb (BonoboUIComponent *uic,
                                                    GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
                                                    GTK_STOCK_HELP, GTK_RESPONSE_HELP,
                                                    NULL);
-	gnome_window_icon_set_from_file (GTK_WINDOW (dialog), GNOME_ICONDIR"/mixer/gnome-mixer-applet.png");	
+	gnome_window_icon_set_from_file (GTK_WINDOW (dialog), GNOME_ICONDIR "gnome-mixer-applet.png");	
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_screen (GTK_WINDOW (dialog),
@@ -1841,6 +1884,11 @@ mixer_applet_create (PanelApplet *applet)
 	device = g_strdup_printf("%sctl",ctl);
 	retval = openMixer(device, data);
 #endif
+#ifdef AIX_API
+	if (!(device = g_getenv("AUDIODEV")))
+		device = "/dev/paud0";
+	retval = openMixer(device, data);
+#endif
 #ifdef GSTREAMER_API
 	retval = gstreamer_init (data);
 #endif
